Springheel_jacky Documentation — springheel_jacky 1.0.0 documentation

Skip to main content

# Springheel_jacky Documentation

This is a simple Python library and command-line tool to work with Springheel sites without scraping. When generating a site, Springheel creates a JSON endpoints file; parsing this file allows programs to request resources from the site easily, without mucking around in the HTML. It’s not quite an API, but for a static site, it’s close enough.

springheel_jacky depends on:

- requests

- html-text

Contents:

- springheel_jacky
  - springheel_jacky package
    - Submodules
    - springheel_jacky.categories module
    - springheel_jacky.chapters module
    - springheel_jacky.cli module
    - springheel_jacky.cbz module
    - springheel_jacky.images module
    - springheel_jacky.internet module
    - springheel_jacky.links module
    - springheel_jacky.search module
    - springheel_jacky.strips module
    - Module contents
- JSON API
  - Site
  - Categories
  - Strips
  - Characters
  - Tags
  - Chapters
- springheel_jacky man page
  - Synopsis
  - Description
  - Options
- Changelog
  - 1.0

# Indices and tables

- Index

- Module Index

- Search Page